@@ -11,6 +11,7 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 import time
+import threading
 
 from concurrent.futures import CancelledError
 
@@ -18,6 +19,7 @@ from botocore.compat import six
 from tests import skip_if_using_serial_implementation
 from tests import RecordingSubscriber, NonSeekableReader
 from tests.integration import BaseTransferManagerIntegTest
+from tests.integration import WaitForTransferStart
 from s3transfer.manager import TransferConfig
 
 
@@ -62,16 +64,23 @@ class TestUpload(BaseTransferManagerIntegTest):
         filename = self.get_input_fileobj(
             name='foo.txt', size=20 * 1024 * 1024)
 
-        sleep_time = 0.25
+        timeout = 10
+        bytes_transferring = threading.Event()
+        subscriber = WaitForTransferStart(bytes_transferring)
         try:
             with transfer_manager:
-                start_time = time.time()
                 future = transfer_manager.upload(
-                    filename, self.bucket_name, '20mb.txt')
-                # Sleep for a little to get the transfer process going
-                time.sleep(sleep_time)
+                    filename, self.bucket_name, '20mb.txt',
+                    subscribers=[subscriber]
+                )
+                if not bytes_transferring.wait(timeout):
+                    future.cancel()
+                    raise RuntimeError(
+                        "Download transfer did not start after waiting for "
+                        "%s seconds." % timeout)
                 # Raise an exception which should cause the preceeding
                 # download to cancel and exit quickly
+                start_time = time.time()
                 raise KeyboardInterrupt()
         except KeyboardInterrupt:
             pass
@@ -79,11 +88,12 @@ class TestUpload(BaseTransferManagerIntegTest):
         # The maximum time allowed for the transfer manager to exit.
         # This means that it should take less than a couple second after
         # sleeping to exit.
-        max_allowed_exit_time = sleep_time + 5
+        max_allowed_exit_time = 5
+        actual_time_to_exit = end_time - start_time
         self.assertLess(
-            end_time - start_time, max_allowed_exit_time,
+            actual_time_to_exit, max_allowed_exit_time,
             "Failed to exit under %s. Instead exited in %s." % (
-                max_allowed_exit_time, end_time - start_time)
+                max_allowed_exit_time, actual_time_to_exit)
         )
 
         try:
@@ -95,8 +105,7 @@ class TestUpload(BaseTransferManagerIntegTest):
             self.assertEqual(str(e), 'KeyboardInterrupt()')
             # If the transfer did get cancelled,
             # make sure the object does not exist.
-            self.assertFalse(self.object_exists('20mb.txt'))
-
+            self.assertTrue(self.object_not_exists('20mb.txt'))
 
     @skip_if_using_serial_implementation(
         'Exception is thrown once the transfers are submitted. '
@@ -123,12 +132,12 @@ class TestUpload(BaseTransferManagerIntegTest):
 
         try:
             with transfer_manager:
-                start_time = time.time()
                 for i, fileobj in enumerate(fileobjs):
                     futures.append(transfer_manager.upload(
                         fileobj, self.bucket_name, keynames[i]))
                 # Raise an exception which should cause the preceeding
                 # transfer to cancel and exit quickly
+                start_time = time.time()
                 raise KeyboardInterrupt()
         except KeyboardInterrupt:
             pass
@@ -148,7 +157,7 @@ class TestUpload(BaseTransferManagerIntegTest):
                 future.result()
         # For the transfer that did get cancelled, make sure the object
         # does not exist.
-        self.assertFalse(self.object_exists(future.meta.call_args.key))
+        self.assertTrue(self.object_not_exists(future.meta.call_args.key))
 
     def test_progress_subscribers_on_upload(self):
         subscriber = RecordingSubscriber()
